# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: C_StreamGrpc.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ansys.api.mapdl.v0.ansys_kernel_pb2 as ansys__kernel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='C_StreamGrpc.proto',
  package='ansys.api.grpcstream.v0',
  syntax='proto3',
  serialized_options=_b('\252\002\027Ansys.Api.GrpcStream.V0'),
  serialized_pb=_b('\n\x12\x43_StreamGrpc.proto\x12\x17\x61nsys.api.grpcstream.v0\x1a\x12\x61nsys_kernel.proto\"-\n\x0bOpenRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04mode\x18\x02 \x01(\x05\",\n\x0cOpenResponse\x12\x0f\n\x07succeed\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t\" \n\x0c\x43loseRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\"-\n\rCloseResponse\x12\x0f\n\x07succeed\x18\x01 \x01(\x08\x12\x0b\n\x03msg\x18\x02 \x01(\t\"?\n\x0bSeekRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0e\n\x06offset\x18\x02 \x01(\x03\x12\x0e\n\x06whence\x18\x03 \x01(\x05\"\x1e\n\x0cSeekResponse\x12\x0e\n\x06offset\x18\x01 \x01(\x03\"\x1f\n\x0bTellRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\"\x1e\n\x0cTellResponse\x12\x0e\n\x06offset\x18\x01 \x01(\x03\"d\n\x0bReadRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x35\n\tstreamreq\x18\x02 \x01(\x0b\x32\".ansys.api.kernel.v0.StreamRequest\x12\x0c\n\x04size\x18\x03 \x01(\x03\".\n\x0cWriteRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0c\n\x04size\x18\x02 \x01(\x03\"\x0f\n\rWriteResponse2\x87\x04\n\x13\x43_StreamGrpcService\x12S\n\x04Open\x12$.ansys.api.grpcstream.v0.OpenRequest\x1a%.ansys.api.grpcstream.v0.OpenResponse\x12V\n\x05\x43lose\x12%.ansys.api.grpcstream.v0.CloseRequest\x1a&.ansys.api.grpcstream.v0.CloseResponse\x12S\n\x04Seek\x12$.ansys.api.grpcstream.v0.SeekRequest\x1a%.ansys.api.grpcstream.v0.SeekResponse\x12S\n\x04Tell\x12$.ansys.api.grpcstream.v0.TellRequest\x1a%.ansys.api.grpcstream.v0.TellResponse\x12J\n\x04Read\x12$.ansys.api.grpcstream.v0.ReadRequest\x1a\x1a.ansys.api.kernel.v0.Chunk0\x01\x12M\n\x05Write\x12\x1a.ansys.api.kernel.v0.Chunk\x1a&.ansys.api.grpcstream.v0.WriteResponse(\x01\x42\x1a\xaa\x02\x17\x41nsys.Api.GrpcStream.V0b\x06proto3')
  ,
  dependencies=[ansys__kernel__pb2.DESCRIPTOR,])




_OPENREQUEST = _descriptor.Descriptor(
  name='OpenRequest',
  full_name='ansys.api.grpcstream.v0.OpenRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='ansys.api.grpcstream.v0.OpenRequest.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mode', full_name='ansys.api.grpcstream.v0.OpenRequest.mode', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=67,
  serialized_end=112,
)


_OPENRESPONSE = _descriptor.Descriptor(
  name='OpenResponse',
  full_name='ansys.api.grpcstream.v0.OpenResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='succeed', full_name='ansys.api.grpcstream.v0.OpenResponse.succeed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='ansys.api.grpcstream.v0.OpenResponse.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=114,
  serialized_end=158,
)


_CLOSEREQUEST = _descriptor.Descriptor(
  name='CloseRequest',
  full_name='ansys.api.grpcstream.v0.CloseRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='ansys.api.grpcstream.v0.CloseRequest.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=160,
  serialized_end=192,
)


_CLOSERESPONSE = _descriptor.Descriptor(
  name='CloseResponse',
  full_name='ansys.api.grpcstream.v0.CloseResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='succeed', full_name='ansys.api.grpcstream.v0.CloseResponse.succeed', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='msg', full_name='ansys.api.grpcstream.v0.CloseResponse.msg', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=194,
  serialized_end=239,
)


_SEEKREQUEST = _descriptor.Descriptor(
  name='SeekRequest',
  full_name='ansys.api.grpcstream.v0.SeekRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='ansys.api.grpcstream.v0.SeekRequest.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='offset', full_name='ansys.api.grpcstream.v0.SeekRequest.offset', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='whence', full_name='ansys.api.grpcstream.v0.SeekRequest.whence', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=241,
  serialized_end=304,
)


_SEEKRESPONSE = _descriptor.Descriptor(
  name='SeekResponse',
  full_name='ansys.api.grpcstream.v0.SeekResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='ansys.api.grpcstream.v0.SeekResponse.offset', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=306,
  serialized_end=336,
)


_TELLREQUEST = _descriptor.Descriptor(
  name='TellRequest',
  full_name='ansys.api.grpcstream.v0.TellRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='ansys.api.grpcstream.v0.TellRequest.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=338,
  serialized_end=369,
)


_TELLRESPONSE = _descriptor.Descriptor(
  name='TellResponse',
  full_name='ansys.api.grpcstream.v0.TellResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='offset', full_name='ansys.api.grpcstream.v0.TellResponse.offset', index=0,
      number=1, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=371,
  serialized_end=401,
)


_READREQUEST = _descriptor.Descriptor(
  name='ReadRequest',
  full_name='ansys.api.grpcstream.v0.ReadRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='ansys.api.grpcstream.v0.ReadRequest.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='streamreq', full_name='ansys.api.grpcstream.v0.ReadRequest.streamreq', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='ansys.api.grpcstream.v0.ReadRequest.size', index=2,
      number=3, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=403,
  serialized_end=503,
)


_WRITEREQUEST = _descriptor.Descriptor(
  name='WriteRequest',
  full_name='ansys.api.grpcstream.v0.WriteRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='ansys.api.grpcstream.v0.WriteRequest.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='ansys.api.grpcstream.v0.WriteRequest.size', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=505,
  serialized_end=551,
)


_WRITERESPONSE = _descriptor.Descriptor(
  name='WriteResponse',
  full_name='ansys.api.grpcstream.v0.WriteResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=553,
  serialized_end=568,
)

_READREQUEST.fields_by_name['streamreq'].message_type = ansys__kernel__pb2._STREAMREQUEST
DESCRIPTOR.message_types_by_name['OpenRequest'] = _OPENREQUEST
DESCRIPTOR.message_types_by_name['OpenResponse'] = _OPENRESPONSE
DESCRIPTOR.message_types_by_name['CloseRequest'] = _CLOSEREQUEST
DESCRIPTOR.message_types_by_name['CloseResponse'] = _CLOSERESPONSE
DESCRIPTOR.message_types_by_name['SeekRequest'] = _SEEKREQUEST
DESCRIPTOR.message_types_by_name['SeekResponse'] = _SEEKRESPONSE
DESCRIPTOR.message_types_by_name['TellRequest'] = _TELLREQUEST
DESCRIPTOR.message_types_by_name['TellResponse'] = _TELLRESPONSE
DESCRIPTOR.message_types_by_name['ReadRequest'] = _READREQUEST
DESCRIPTOR.message_types_by_name['WriteRequest'] = _WRITEREQUEST
DESCRIPTOR.message_types_by_name['WriteResponse'] = _WRITERESPONSE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

OpenRequest = _reflection.GeneratedProtocolMessageType('OpenRequest', (_message.Message,), dict(
  DESCRIPTOR = _OPENREQUEST,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.OpenRequest)
  ))
_sym_db.RegisterMessage(OpenRequest)

OpenResponse = _reflection.GeneratedProtocolMessageType('OpenResponse', (_message.Message,), dict(
  DESCRIPTOR = _OPENRESPONSE,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.OpenResponse)
  ))
_sym_db.RegisterMessage(OpenResponse)

CloseRequest = _reflection.GeneratedProtocolMessageType('CloseRequest', (_message.Message,), dict(
  DESCRIPTOR = _CLOSEREQUEST,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.CloseRequest)
  ))
_sym_db.RegisterMessage(CloseRequest)

CloseResponse = _reflection.GeneratedProtocolMessageType('CloseResponse', (_message.Message,), dict(
  DESCRIPTOR = _CLOSERESPONSE,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.CloseResponse)
  ))
_sym_db.RegisterMessage(CloseResponse)

SeekRequest = _reflection.GeneratedProtocolMessageType('SeekRequest', (_message.Message,), dict(
  DESCRIPTOR = _SEEKREQUEST,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.SeekRequest)
  ))
_sym_db.RegisterMessage(SeekRequest)

SeekResponse = _reflection.GeneratedProtocolMessageType('SeekResponse', (_message.Message,), dict(
  DESCRIPTOR = _SEEKRESPONSE,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.SeekResponse)
  ))
_sym_db.RegisterMessage(SeekResponse)

TellRequest = _reflection.GeneratedProtocolMessageType('TellRequest', (_message.Message,), dict(
  DESCRIPTOR = _TELLREQUEST,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.TellRequest)
  ))
_sym_db.RegisterMessage(TellRequest)

TellResponse = _reflection.GeneratedProtocolMessageType('TellResponse', (_message.Message,), dict(
  DESCRIPTOR = _TELLRESPONSE,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.TellResponse)
  ))
_sym_db.RegisterMessage(TellResponse)

ReadRequest = _reflection.GeneratedProtocolMessageType('ReadRequest', (_message.Message,), dict(
  DESCRIPTOR = _READREQUEST,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.ReadRequest)
  ))
_sym_db.RegisterMessage(ReadRequest)

WriteRequest = _reflection.GeneratedProtocolMessageType('WriteRequest', (_message.Message,), dict(
  DESCRIPTOR = _WRITEREQUEST,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.WriteRequest)
  ))
_sym_db.RegisterMessage(WriteRequest)

WriteResponse = _reflection.GeneratedProtocolMessageType('WriteResponse', (_message.Message,), dict(
  DESCRIPTOR = _WRITERESPONSE,
  __module__ = 'C_StreamGrpc_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.grpcstream.v0.WriteResponse)
  ))
_sym_db.RegisterMessage(WriteResponse)


DESCRIPTOR._options = None

_C_STREAMGRPCSERVICE = _descriptor.ServiceDescriptor(
  name='C_StreamGrpcService',
  full_name='ansys.api.grpcstream.v0.C_StreamGrpcService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=571,
  serialized_end=1090,
  methods=[
  _descriptor.MethodDescriptor(
    name='Open',
    full_name='ansys.api.grpcstream.v0.C_StreamGrpcService.Open',
    index=0,
    containing_service=None,
    input_type=_OPENREQUEST,
    output_type=_OPENRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Close',
    full_name='ansys.api.grpcstream.v0.C_StreamGrpcService.Close',
    index=1,
    containing_service=None,
    input_type=_CLOSEREQUEST,
    output_type=_CLOSERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Seek',
    full_name='ansys.api.grpcstream.v0.C_StreamGrpcService.Seek',
    index=2,
    containing_service=None,
    input_type=_SEEKREQUEST,
    output_type=_SEEKRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Tell',
    full_name='ansys.api.grpcstream.v0.C_StreamGrpcService.Tell',
    index=3,
    containing_service=None,
    input_type=_TELLREQUEST,
    output_type=_TELLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Read',
    full_name='ansys.api.grpcstream.v0.C_StreamGrpcService.Read',
    index=4,
    containing_service=None,
    input_type=_READREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Write',
    full_name='ansys.api.grpcstream.v0.C_StreamGrpcService.Write',
    index=5,
    containing_service=None,
    input_type=ansys__kernel__pb2._CHUNK,
    output_type=_WRITERESPONSE,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_C_STREAMGRPCSERVICE)

DESCRIPTOR.services_by_name['C_StreamGrpcService'] = _C_STREAMGRPCSERVICE

# @@protoc_insertion_point(module_scope)
