# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: mapdl.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ansys.api.mapdl.v0.ansys_kernel_pb2 as ansys__kernel__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='mapdl.proto',
  package='ansys.api.mapdl.v0',
  syntax='proto3',
  serialized_options=_b('\252\002\022Ansys.Api.Mapdl.V0'),
  serialized_pb=_b('\n\x0bmapdl.proto\x12\x12\x61nsys.api.mapdl.v0\x1a\x12\x61nsys_kernel.proto\"*\n\nCmdRequest\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x0b\n\x03opt\x18\x02 \x01(\t\"B\n\x0b\x43mdResponse\x12\x10\n\x08response\x18\x01 \x01(\t\x12\x0e\n\x06status\x18\x02 \x01(\x05\x12\x11\n\terror_msg\x18\x03 \x01(\t\"1\n\x10InputFileRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x0b\n\x03opt\x18\x02 \x01(\t\",\n\tCmdOutput\x12\x0f\n\x07msgtype\x18\x01 \x01(\x05\x12\x0e\n\x06\x63mdout\x18\x02 \x03(\t\"C\n\x06\x46\x63tArg\x12,\n\x04type\x18\x01 \x01(\x0e\x32\x1e.ansys.api.kernel.v0.ValueType\x12\x0b\n\x03val\x18\x02 \x03(\t\"a\n\x0e\x46\x63tCallRequest\x12\x10\n\x08\x66\x63t_name\x18\x01 \x01(\t\x12(\n\x04\x61rgs\x18\x02 \x03(\x0b\x32\x1a.ansys.api.mapdl.v0.FctArg\x12\x13\n\x0breturns_arg\x18\x03 \x01(\x08\"?\n\x0f\x46\x63tCallResponse\x12,\n\x08\x66\x65\x65\x64\x62\x61\x63k\x18\x01 \x01(\x0b\x32\x1a.ansys.api.mapdl.v0.FctArg\"\x1a\n\x0bNodeRequest\x12\x0b\n\x03num\x18\x01 \x01(\x05\"7\n\x0cNodeResponse\x12\'\n\x04node\x18\x01 \x01(\x0b\x32\x19.ansys.api.kernel.v0.Node\"9\n\x0esetNodeRequest\x12\'\n\x04node\x18\x01 \x01(\x0b\x32\x19.ansys.api.kernel.v0.Node\"\x1e\n\x0fsetNodeResponse\x12\x0b\n\x03num\x18\x01 \x01(\x05\"\x1d\n\x0e\x45lementRequest\x12\x0b\n\x03num\x18\x01 \x01(\x05\"\x7f\n\x07\x45lement\x12\n\n\x02id\x18\x01 \x01(\x05\x12\x0b\n\x03mat\x18\x02 \x01(\x05\x12\x0c\n\x04type\x18\x03 \x01(\x05\x12\x0c\n\x04real\x18\x04 \x01(\x05\x12\x0c\n\x04sect\x18\x05 \x01(\x05\x12\n\n\x02\x63s\x18\x06 \x01(\x05\x12\x12\n\nnode_count\x18\x07 \x01(\x05\x12\x11\n\tnodes_ids\x18\x08 \x03(\x05\";\n\x0f\x45lementResponse\x12(\n\x03\x65lm\x18\x01 \x01(\x0b\x32\x1b.ansys.api.mapdl.v0.Element\"\x1f\n\x0b\x45lementType\x12\x10\n\x04ielc\x18\x01 \x03(\x05\x42\x02\x10\x01\"/\n\x10ParameterRequest\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\r\n\x05\x61rray\x18\x02 \x01(\x08\"<\n\x11ParameterResponse\x12\x0b\n\x03val\x18\x01 \x03(\x01\x12\x0c\n\x04sval\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"\x1f\n\x0fVariableRequest\x12\x0c\n\x04inum\x18\x01 \x01(\x05\"\x1f\n\x10VariableResponse\x12\x0b\n\x03val\x18\x01 \x03(\x01\"\x1c\n\nGetRequest\x12\x0e\n\x06getcmd\x18\x01 \x01(\t\"7\n\x0bGetResponse\x12\x0c\n\x04\x64val\x18\x01 \x01(\x01\x12\x0c\n\x04sval\x18\x02 \x01(\t\x12\x0c\n\x04type\x18\x03 \x01(\x05\"\x8a\x01\n\x0c\x44\x61taResponse\x12-\n\x05stype\x18\x01 \x01(\x0e\x32\x1e.ansys.api.kernel.v0.ValueType\x12-\n\x07objtype\x18\x02 \x01(\x0e\x32\x1c.ansys.api.mapdl.v0.DataType\x12\r\n\x05size1\x18\x03 \x01(\x05\x12\r\n\x05size2\x18\x04 \x01(\x05\"\x8a\x01\n\x11SetVecDataRequest\x12\r\n\x05vname\x18\x01 \x01(\t\x12-\n\x05stype\x18\x02 \x01(\x0e\x32\x1e.ansys.api.kernel.v0.ValueType\x12\x0c\n\x04size\x18\x03 \x01(\x05\x12)\n\x05\x63hunk\x18\x04 \x01(\x0b\x32\x1a.ansys.api.kernel.v0.Chunk\"\x98\x01\n\x11SetMatDataRequest\x12\r\n\x05mname\x18\x01 \x01(\t\x12-\n\x05stype\x18\x02 \x01(\x0e\x32\x1e.ansys.api.kernel.v0.ValueType\x12\x0c\n\x04nrow\x18\x03 \x01(\x05\x12\x0c\n\x04ncol\x18\x04 \x01(\x05\x12)\n\x05\x63hunk\x18\x05 \x01(\x0b\x32\x1a.ansys.api.kernel.v0.Chunk\"Q\n\x11UploadFileRequest\x12\x11\n\tfile_name\x18\x01 \x01(\t\x12)\n\x05\x63hunk\x18\x02 \x01(\x0b\x32\x1a.ansys.api.kernel.v0.Chunk\"!\n\x0fUploadFileReply\x12\x0e\n\x06length\x18\x01 \x01(\x05\"#\n\x13\x44ownloadFileRequest\x12\x0c\n\x04name\x18\x01 \x01(\t*0\n\x08\x44\x61taType\x12\x07\n\x03GEN\x10\x00\x12\x07\n\x03VEC\x10\x01\x12\x08\n\x04\x44MAT\x10\x02\x12\x08\n\x04SMAT\x10\x03\x32\xfa\x12\n\x0cMapdlService\x12N\n\x0bSendCommand\x12\x1e.ansys.api.mapdl.v0.CmdRequest\x1a\x1f.ansys.api.mapdl.v0.CmdResponse\x12O\n\x0cSendCommandS\x12\x1e.ansys.api.mapdl.v0.CmdRequest\x1a\x1d.ansys.api.mapdl.v0.CmdOutput0\x01\x12P\n\x0eInputFileLocal\x12\x1e.ansys.api.mapdl.v0.CmdRequest\x1a\x1a.ansys.api.kernel.v0.Chunk(\x01\x30\x01\x12O\n\tInputFile\x12$.ansys.api.mapdl.v0.InputFileRequest\x1a\x1a.ansys.api.kernel.v0.Chunk0\x01\x12S\n\nInputFileS\x12$.ansys.api.mapdl.v0.InputFileRequest\x1a\x1d.ansys.api.mapdl.v0.CmdOutput0\x01\x12R\n\x07\x46\x63tCall\x12\".ansys.api.mapdl.v0.FctCallRequest\x1a#.ansys.api.mapdl.v0.FctCallResponse\x12J\n\x08GetNodes\x12!.ansys.api.kernel.v0.EmptyRequest\x1a\x19.ansys.api.kernel.v0.Node0\x01\x12L\n\x07GetNode\x12\x1f.ansys.api.mapdl.v0.NodeRequest\x1a .ansys.api.mapdl.v0.NodeResponse\x12R\n\x07SetNode\x12\".ansys.api.mapdl.v0.setNodeRequest\x1a#.ansys.api.mapdl.v0.setNodeResponse\x12H\n\x05Nodes\x12!.ansys.api.kernel.v0.EmptyRequest\x1a\x1a.ansys.api.kernel.v0.Chunk0\x01\x12O\n\x0bGetElements\x12!.ansys.api.kernel.v0.EmptyRequest\x1a\x1b.ansys.api.mapdl.v0.Element0\x01\x12U\n\nGetElement\x12\".ansys.api.mapdl.v0.ElementRequest\x1a#.ansys.api.mapdl.v0.ElementResponse\x12O\n\x0cLoadElements\x12!.ansys.api.kernel.v0.EmptyRequest\x1a\x1a.ansys.api.kernel.v0.Chunk0\x01\x12U\n\x0eGetElementType\x12\".ansys.api.mapdl.v0.ElementRequest\x1a\x1f.ansys.api.mapdl.v0.ElementType\x12]\n\x1aLoadElementTypeDescription\x12!.ansys.api.kernel.v0.EmptyRequest\x1a\x1a.ansys.api.kernel.v0.Chunk0\x01\x12[\n\x0cGetParameter\x12$.ansys.api.mapdl.v0.ParameterRequest\x1a%.ansys.api.mapdl.v0.ParameterResponse\x12X\n\x0bGetVariable\x12#.ansys.api.mapdl.v0.VariableRequest\x1a$.ansys.api.mapdl.v0.VariableResponse\x12\x46\n\x03Get\x12\x1e.ansys.api.mapdl.v0.GetRequest\x1a\x1f.ansys.api.mapdl.v0.GetResponse\x12L\n\x04VGet\x12\x1e.ansys.api.mapdl.v0.GetRequest\x1a$.ansys.api.mapdl.v0.VariableResponse\x12\x45\n\x05VGet2\x12\x1e.ansys.api.mapdl.v0.GetRequest\x1a\x1a.ansys.api.kernel.v0.Chunk0\x01\x12K\n\x04\x43trl\x12 .ansys.api.kernel.v0.CtrlRequest\x1a!.ansys.api.kernel.v0.CtrlResponse\x12Q\n\x0eGetVtkGeometry\x12!.ansys.api.kernel.v0.EmptyRequest\x1a\x1a.ansys.api.kernel.v0.Chunk0\x01\x12U\n\x0bGetDataInfo\x12$.ansys.api.mapdl.v0.ParameterRequest\x1a .ansys.api.mapdl.v0.DataResponse\x12P\n\nGetVecData\x12$.ansys.api.mapdl.v0.ParameterRequest\x1a\x1a.ansys.api.kernel.v0.Chunk0\x01\x12P\n\nGetMatData\x12$.ansys.api.mapdl.v0.ParameterRequest\x1a\x1a.ansys.api.kernel.v0.Chunk0\x01\x12Y\n\nSetVecData\x12%.ansys.api.mapdl.v0.SetVecDataRequest\x1a\".ansys.api.kernel.v0.EmptyResponse(\x01\x12Y\n\nSetMatData\x12%.ansys.api.mapdl.v0.SetMatDataRequest\x1a\".ansys.api.kernel.v0.EmptyResponse(\x01\x12Z\n\nUploadFile\x12%.ansys.api.mapdl.v0.UploadFileRequest\x1a#.ansys.api.mapdl.v0.UploadFileReply(\x01\x12U\n\x0c\x44ownloadFile\x12\'.ansys.api.mapdl.v0.DownloadFileRequest\x1a\x1a.ansys.api.kernel.v0.Chunk0\x01\x42\x15\xaa\x02\x12\x41nsys.Api.Mapdl.V0b\x06proto3')
  ,
  dependencies=[ansys__kernel__pb2.DESCRIPTOR,])

_DATATYPE = _descriptor.EnumDescriptor(
  name='DataType',
  full_name='ansys.api.mapdl.v0.DataType',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='GEN', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='VEC', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DMAT', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SMAT', index=3, number=3,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=1783,
  serialized_end=1831,
)
_sym_db.RegisterEnumDescriptor(_DATATYPE)

DataType = enum_type_wrapper.EnumTypeWrapper(_DATATYPE)
GEN = 0
VEC = 1
DMAT = 2
SMAT = 3



_CMDREQUEST = _descriptor.Descriptor(
  name='CmdRequest',
  full_name='ansys.api.mapdl.v0.CmdRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='command', full_name='ansys.api.mapdl.v0.CmdRequest.command', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opt', full_name='ansys.api.mapdl.v0.CmdRequest.opt', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=55,
  serialized_end=97,
)


_CMDRESPONSE = _descriptor.Descriptor(
  name='CmdResponse',
  full_name='ansys.api.mapdl.v0.CmdResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='response', full_name='ansys.api.mapdl.v0.CmdResponse.response', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='status', full_name='ansys.api.mapdl.v0.CmdResponse.status', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='error_msg', full_name='ansys.api.mapdl.v0.CmdResponse.error_msg', index=2,
      number=3, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=99,
  serialized_end=165,
)


_INPUTFILEREQUEST = _descriptor.Descriptor(
  name='InputFileRequest',
  full_name='ansys.api.mapdl.v0.InputFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='filename', full_name='ansys.api.mapdl.v0.InputFileRequest.filename', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='opt', full_name='ansys.api.mapdl.v0.InputFileRequest.opt', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=167,
  serialized_end=216,
)


_CMDOUTPUT = _descriptor.Descriptor(
  name='CmdOutput',
  full_name='ansys.api.mapdl.v0.CmdOutput',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='msgtype', full_name='ansys.api.mapdl.v0.CmdOutput.msgtype', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cmdout', full_name='ansys.api.mapdl.v0.CmdOutput.cmdout', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=218,
  serialized_end=262,
)


_FCTARG = _descriptor.Descriptor(
  name='FctArg',
  full_name='ansys.api.mapdl.v0.FctArg',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='type', full_name='ansys.api.mapdl.v0.FctArg.type', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='val', full_name='ansys.api.mapdl.v0.FctArg.val', index=1,
      number=2, type=9, cpp_type=9, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=264,
  serialized_end=331,
)


_FCTCALLREQUEST = _descriptor.Descriptor(
  name='FctCallRequest',
  full_name='ansys.api.mapdl.v0.FctCallRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='fct_name', full_name='ansys.api.mapdl.v0.FctCallRequest.fct_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='args', full_name='ansys.api.mapdl.v0.FctCallRequest.args', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='returns_arg', full_name='ansys.api.mapdl.v0.FctCallRequest.returns_arg', index=2,
      number=3, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=333,
  serialized_end=430,
)


_FCTCALLRESPONSE = _descriptor.Descriptor(
  name='FctCallResponse',
  full_name='ansys.api.mapdl.v0.FctCallResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='feedback', full_name='ansys.api.mapdl.v0.FctCallResponse.feedback', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=432,
  serialized_end=495,
)


_NODEREQUEST = _descriptor.Descriptor(
  name='NodeRequest',
  full_name='ansys.api.mapdl.v0.NodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num', full_name='ansys.api.mapdl.v0.NodeRequest.num', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=497,
  serialized_end=523,
)


_NODERESPONSE = _descriptor.Descriptor(
  name='NodeResponse',
  full_name='ansys.api.mapdl.v0.NodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='ansys.api.mapdl.v0.NodeResponse.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=525,
  serialized_end=580,
)


_SETNODEREQUEST = _descriptor.Descriptor(
  name='setNodeRequest',
  full_name='ansys.api.mapdl.v0.setNodeRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='node', full_name='ansys.api.mapdl.v0.setNodeRequest.node', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=582,
  serialized_end=639,
)


_SETNODERESPONSE = _descriptor.Descriptor(
  name='setNodeResponse',
  full_name='ansys.api.mapdl.v0.setNodeResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num', full_name='ansys.api.mapdl.v0.setNodeResponse.num', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=641,
  serialized_end=671,
)


_ELEMENTREQUEST = _descriptor.Descriptor(
  name='ElementRequest',
  full_name='ansys.api.mapdl.v0.ElementRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='num', full_name='ansys.api.mapdl.v0.ElementRequest.num', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=673,
  serialized_end=702,
)


_ELEMENT = _descriptor.Descriptor(
  name='Element',
  full_name='ansys.api.mapdl.v0.Element',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='id', full_name='ansys.api.mapdl.v0.Element.id', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='mat', full_name='ansys.api.mapdl.v0.Element.mat', index=1,
      number=2, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='ansys.api.mapdl.v0.Element.type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='real', full_name='ansys.api.mapdl.v0.Element.real', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sect', full_name='ansys.api.mapdl.v0.Element.sect', index=4,
      number=5, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='cs', full_name='ansys.api.mapdl.v0.Element.cs', index=5,
      number=6, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='node_count', full_name='ansys.api.mapdl.v0.Element.node_count', index=6,
      number=7, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nodes_ids', full_name='ansys.api.mapdl.v0.Element.nodes_ids', index=7,
      number=8, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=704,
  serialized_end=831,
)


_ELEMENTRESPONSE = _descriptor.Descriptor(
  name='ElementResponse',
  full_name='ansys.api.mapdl.v0.ElementResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='elm', full_name='ansys.api.mapdl.v0.ElementResponse.elm', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=833,
  serialized_end=892,
)


_ELEMENTTYPE = _descriptor.Descriptor(
  name='ElementType',
  full_name='ansys.api.mapdl.v0.ElementType',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='ielc', full_name='ansys.api.mapdl.v0.ElementType.ielc', index=0,
      number=1, type=5, cpp_type=1, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=_b('\020\001'), file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=894,
  serialized_end=925,
)


_PARAMETERREQUEST = _descriptor.Descriptor(
  name='ParameterRequest',
  full_name='ansys.api.mapdl.v0.ParameterRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ansys.api.mapdl.v0.ParameterRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='array', full_name='ansys.api.mapdl.v0.ParameterRequest.array', index=1,
      number=2, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=927,
  serialized_end=974,
)


_PARAMETERRESPONSE = _descriptor.Descriptor(
  name='ParameterResponse',
  full_name='ansys.api.mapdl.v0.ParameterResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='ansys.api.mapdl.v0.ParameterResponse.val', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sval', full_name='ansys.api.mapdl.v0.ParameterResponse.sval', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='ansys.api.mapdl.v0.ParameterResponse.type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=976,
  serialized_end=1036,
)


_VARIABLEREQUEST = _descriptor.Descriptor(
  name='VariableRequest',
  full_name='ansys.api.mapdl.v0.VariableRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='inum', full_name='ansys.api.mapdl.v0.VariableRequest.inum', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1038,
  serialized_end=1069,
)


_VARIABLERESPONSE = _descriptor.Descriptor(
  name='VariableResponse',
  full_name='ansys.api.mapdl.v0.VariableResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='val', full_name='ansys.api.mapdl.v0.VariableResponse.val', index=0,
      number=1, type=1, cpp_type=5, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1071,
  serialized_end=1102,
)


_GETREQUEST = _descriptor.Descriptor(
  name='GetRequest',
  full_name='ansys.api.mapdl.v0.GetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='getcmd', full_name='ansys.api.mapdl.v0.GetRequest.getcmd', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1104,
  serialized_end=1132,
)


_GETRESPONSE = _descriptor.Descriptor(
  name='GetResponse',
  full_name='ansys.api.mapdl.v0.GetResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='dval', full_name='ansys.api.mapdl.v0.GetResponse.dval', index=0,
      number=1, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='sval', full_name='ansys.api.mapdl.v0.GetResponse.sval', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='type', full_name='ansys.api.mapdl.v0.GetResponse.type', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1134,
  serialized_end=1189,
)


_DATARESPONSE = _descriptor.Descriptor(
  name='DataResponse',
  full_name='ansys.api.mapdl.v0.DataResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='stype', full_name='ansys.api.mapdl.v0.DataResponse.stype', index=0,
      number=1, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='objtype', full_name='ansys.api.mapdl.v0.DataResponse.objtype', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size1', full_name='ansys.api.mapdl.v0.DataResponse.size1', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size2', full_name='ansys.api.mapdl.v0.DataResponse.size2', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1192,
  serialized_end=1330,
)


_SETVECDATAREQUEST = _descriptor.Descriptor(
  name='SetVecDataRequest',
  full_name='ansys.api.mapdl.v0.SetVecDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='vname', full_name='ansys.api.mapdl.v0.SetVecDataRequest.vname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stype', full_name='ansys.api.mapdl.v0.SetVecDataRequest.stype', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='size', full_name='ansys.api.mapdl.v0.SetVecDataRequest.size', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunk', full_name='ansys.api.mapdl.v0.SetVecDataRequest.chunk', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1333,
  serialized_end=1471,
)


_SETMATDATAREQUEST = _descriptor.Descriptor(
  name='SetMatDataRequest',
  full_name='ansys.api.mapdl.v0.SetMatDataRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='mname', full_name='ansys.api.mapdl.v0.SetMatDataRequest.mname', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='stype', full_name='ansys.api.mapdl.v0.SetMatDataRequest.stype', index=1,
      number=2, type=14, cpp_type=8, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='nrow', full_name='ansys.api.mapdl.v0.SetMatDataRequest.nrow', index=2,
      number=3, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='ncol', full_name='ansys.api.mapdl.v0.SetMatDataRequest.ncol', index=3,
      number=4, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunk', full_name='ansys.api.mapdl.v0.SetMatDataRequest.chunk', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1474,
  serialized_end=1626,
)


_UPLOADFILEREQUEST = _descriptor.Descriptor(
  name='UploadFileRequest',
  full_name='ansys.api.mapdl.v0.UploadFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='file_name', full_name='ansys.api.mapdl.v0.UploadFileRequest.file_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='chunk', full_name='ansys.api.mapdl.v0.UploadFileRequest.chunk', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1628,
  serialized_end=1709,
)


_UPLOADFILEREPLY = _descriptor.Descriptor(
  name='UploadFileReply',
  full_name='ansys.api.mapdl.v0.UploadFileReply',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='length', full_name='ansys.api.mapdl.v0.UploadFileReply.length', index=0,
      number=1, type=5, cpp_type=1, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1711,
  serialized_end=1744,
)


_DOWNLOADFILEREQUEST = _descriptor.Descriptor(
  name='DownloadFileRequest',
  full_name='ansys.api.mapdl.v0.DownloadFileRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='name', full_name='ansys.api.mapdl.v0.DownloadFileRequest.name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=1746,
  serialized_end=1781,
)

_FCTARG.fields_by_name['type'].enum_type = ansys__kernel__pb2._VALUETYPE
_FCTCALLREQUEST.fields_by_name['args'].message_type = _FCTARG
_FCTCALLRESPONSE.fields_by_name['feedback'].message_type = _FCTARG
_NODERESPONSE.fields_by_name['node'].message_type = ansys__kernel__pb2._NODE
_SETNODEREQUEST.fields_by_name['node'].message_type = ansys__kernel__pb2._NODE
_ELEMENTRESPONSE.fields_by_name['elm'].message_type = _ELEMENT
_DATARESPONSE.fields_by_name['stype'].enum_type = ansys__kernel__pb2._VALUETYPE
_DATARESPONSE.fields_by_name['objtype'].enum_type = _DATATYPE
_SETVECDATAREQUEST.fields_by_name['stype'].enum_type = ansys__kernel__pb2._VALUETYPE
_SETVECDATAREQUEST.fields_by_name['chunk'].message_type = ansys__kernel__pb2._CHUNK
_SETMATDATAREQUEST.fields_by_name['stype'].enum_type = ansys__kernel__pb2._VALUETYPE
_SETMATDATAREQUEST.fields_by_name['chunk'].message_type = ansys__kernel__pb2._CHUNK
_UPLOADFILEREQUEST.fields_by_name['chunk'].message_type = ansys__kernel__pb2._CHUNK
DESCRIPTOR.message_types_by_name['CmdRequest'] = _CMDREQUEST
DESCRIPTOR.message_types_by_name['CmdResponse'] = _CMDRESPONSE
DESCRIPTOR.message_types_by_name['InputFileRequest'] = _INPUTFILEREQUEST
DESCRIPTOR.message_types_by_name['CmdOutput'] = _CMDOUTPUT
DESCRIPTOR.message_types_by_name['FctArg'] = _FCTARG
DESCRIPTOR.message_types_by_name['FctCallRequest'] = _FCTCALLREQUEST
DESCRIPTOR.message_types_by_name['FctCallResponse'] = _FCTCALLRESPONSE
DESCRIPTOR.message_types_by_name['NodeRequest'] = _NODEREQUEST
DESCRIPTOR.message_types_by_name['NodeResponse'] = _NODERESPONSE
DESCRIPTOR.message_types_by_name['setNodeRequest'] = _SETNODEREQUEST
DESCRIPTOR.message_types_by_name['setNodeResponse'] = _SETNODERESPONSE
DESCRIPTOR.message_types_by_name['ElementRequest'] = _ELEMENTREQUEST
DESCRIPTOR.message_types_by_name['Element'] = _ELEMENT
DESCRIPTOR.message_types_by_name['ElementResponse'] = _ELEMENTRESPONSE
DESCRIPTOR.message_types_by_name['ElementType'] = _ELEMENTTYPE
DESCRIPTOR.message_types_by_name['ParameterRequest'] = _PARAMETERREQUEST
DESCRIPTOR.message_types_by_name['ParameterResponse'] = _PARAMETERRESPONSE
DESCRIPTOR.message_types_by_name['VariableRequest'] = _VARIABLEREQUEST
DESCRIPTOR.message_types_by_name['VariableResponse'] = _VARIABLERESPONSE
DESCRIPTOR.message_types_by_name['GetRequest'] = _GETREQUEST
DESCRIPTOR.message_types_by_name['GetResponse'] = _GETRESPONSE
DESCRIPTOR.message_types_by_name['DataResponse'] = _DATARESPONSE
DESCRIPTOR.message_types_by_name['SetVecDataRequest'] = _SETVECDATAREQUEST
DESCRIPTOR.message_types_by_name['SetMatDataRequest'] = _SETMATDATAREQUEST
DESCRIPTOR.message_types_by_name['UploadFileRequest'] = _UPLOADFILEREQUEST
DESCRIPTOR.message_types_by_name['UploadFileReply'] = _UPLOADFILEREPLY
DESCRIPTOR.message_types_by_name['DownloadFileRequest'] = _DOWNLOADFILEREQUEST
DESCRIPTOR.enum_types_by_name['DataType'] = _DATATYPE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

CmdRequest = _reflection.GeneratedProtocolMessageType('CmdRequest', (_message.Message,), dict(
  DESCRIPTOR = _CMDREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.CmdRequest)
  ))
_sym_db.RegisterMessage(CmdRequest)

CmdResponse = _reflection.GeneratedProtocolMessageType('CmdResponse', (_message.Message,), dict(
  DESCRIPTOR = _CMDRESPONSE,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.CmdResponse)
  ))
_sym_db.RegisterMessage(CmdResponse)

InputFileRequest = _reflection.GeneratedProtocolMessageType('InputFileRequest', (_message.Message,), dict(
  DESCRIPTOR = _INPUTFILEREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.InputFileRequest)
  ))
_sym_db.RegisterMessage(InputFileRequest)

CmdOutput = _reflection.GeneratedProtocolMessageType('CmdOutput', (_message.Message,), dict(
  DESCRIPTOR = _CMDOUTPUT,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.CmdOutput)
  ))
_sym_db.RegisterMessage(CmdOutput)

FctArg = _reflection.GeneratedProtocolMessageType('FctArg', (_message.Message,), dict(
  DESCRIPTOR = _FCTARG,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.FctArg)
  ))
_sym_db.RegisterMessage(FctArg)

FctCallRequest = _reflection.GeneratedProtocolMessageType('FctCallRequest', (_message.Message,), dict(
  DESCRIPTOR = _FCTCALLREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.FctCallRequest)
  ))
_sym_db.RegisterMessage(FctCallRequest)

FctCallResponse = _reflection.GeneratedProtocolMessageType('FctCallResponse', (_message.Message,), dict(
  DESCRIPTOR = _FCTCALLRESPONSE,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.FctCallResponse)
  ))
_sym_db.RegisterMessage(FctCallResponse)

NodeRequest = _reflection.GeneratedProtocolMessageType('NodeRequest', (_message.Message,), dict(
  DESCRIPTOR = _NODEREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.NodeRequest)
  ))
_sym_db.RegisterMessage(NodeRequest)

NodeResponse = _reflection.GeneratedProtocolMessageType('NodeResponse', (_message.Message,), dict(
  DESCRIPTOR = _NODERESPONSE,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.NodeResponse)
  ))
_sym_db.RegisterMessage(NodeResponse)

setNodeRequest = _reflection.GeneratedProtocolMessageType('setNodeRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETNODEREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.setNodeRequest)
  ))
_sym_db.RegisterMessage(setNodeRequest)

setNodeResponse = _reflection.GeneratedProtocolMessageType('setNodeResponse', (_message.Message,), dict(
  DESCRIPTOR = _SETNODERESPONSE,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.setNodeResponse)
  ))
_sym_db.RegisterMessage(setNodeResponse)

ElementRequest = _reflection.GeneratedProtocolMessageType('ElementRequest', (_message.Message,), dict(
  DESCRIPTOR = _ELEMENTREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.ElementRequest)
  ))
_sym_db.RegisterMessage(ElementRequest)

Element = _reflection.GeneratedProtocolMessageType('Element', (_message.Message,), dict(
  DESCRIPTOR = _ELEMENT,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.Element)
  ))
_sym_db.RegisterMessage(Element)

ElementResponse = _reflection.GeneratedProtocolMessageType('ElementResponse', (_message.Message,), dict(
  DESCRIPTOR = _ELEMENTRESPONSE,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.ElementResponse)
  ))
_sym_db.RegisterMessage(ElementResponse)

ElementType = _reflection.GeneratedProtocolMessageType('ElementType', (_message.Message,), dict(
  DESCRIPTOR = _ELEMENTTYPE,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.ElementType)
  ))
_sym_db.RegisterMessage(ElementType)

ParameterRequest = _reflection.GeneratedProtocolMessageType('ParameterRequest', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETERREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.ParameterRequest)
  ))
_sym_db.RegisterMessage(ParameterRequest)

ParameterResponse = _reflection.GeneratedProtocolMessageType('ParameterResponse', (_message.Message,), dict(
  DESCRIPTOR = _PARAMETERRESPONSE,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.ParameterResponse)
  ))
_sym_db.RegisterMessage(ParameterResponse)

VariableRequest = _reflection.GeneratedProtocolMessageType('VariableRequest', (_message.Message,), dict(
  DESCRIPTOR = _VARIABLEREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.VariableRequest)
  ))
_sym_db.RegisterMessage(VariableRequest)

VariableResponse = _reflection.GeneratedProtocolMessageType('VariableResponse', (_message.Message,), dict(
  DESCRIPTOR = _VARIABLERESPONSE,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.VariableResponse)
  ))
_sym_db.RegisterMessage(VariableResponse)

GetRequest = _reflection.GeneratedProtocolMessageType('GetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.GetRequest)
  ))
_sym_db.RegisterMessage(GetRequest)

GetResponse = _reflection.GeneratedProtocolMessageType('GetResponse', (_message.Message,), dict(
  DESCRIPTOR = _GETRESPONSE,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.GetResponse)
  ))
_sym_db.RegisterMessage(GetResponse)

DataResponse = _reflection.GeneratedProtocolMessageType('DataResponse', (_message.Message,), dict(
  DESCRIPTOR = _DATARESPONSE,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.DataResponse)
  ))
_sym_db.RegisterMessage(DataResponse)

SetVecDataRequest = _reflection.GeneratedProtocolMessageType('SetVecDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETVECDATAREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.SetVecDataRequest)
  ))
_sym_db.RegisterMessage(SetVecDataRequest)

SetMatDataRequest = _reflection.GeneratedProtocolMessageType('SetMatDataRequest', (_message.Message,), dict(
  DESCRIPTOR = _SETMATDATAREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.SetMatDataRequest)
  ))
_sym_db.RegisterMessage(SetMatDataRequest)

UploadFileRequest = _reflection.GeneratedProtocolMessageType('UploadFileRequest', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADFILEREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.UploadFileRequest)
  ))
_sym_db.RegisterMessage(UploadFileRequest)

UploadFileReply = _reflection.GeneratedProtocolMessageType('UploadFileReply', (_message.Message,), dict(
  DESCRIPTOR = _UPLOADFILEREPLY,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.UploadFileReply)
  ))
_sym_db.RegisterMessage(UploadFileReply)

DownloadFileRequest = _reflection.GeneratedProtocolMessageType('DownloadFileRequest', (_message.Message,), dict(
  DESCRIPTOR = _DOWNLOADFILEREQUEST,
  __module__ = 'mapdl_pb2'
  # @@protoc_insertion_point(class_scope:ansys.api.mapdl.v0.DownloadFileRequest)
  ))
_sym_db.RegisterMessage(DownloadFileRequest)


DESCRIPTOR._options = None
_ELEMENTTYPE.fields_by_name['ielc']._options = None

_MAPDLSERVICE = _descriptor.ServiceDescriptor(
  name='MapdlService',
  full_name='ansys.api.mapdl.v0.MapdlService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=None,
  serialized_start=1834,
  serialized_end=4260,
  methods=[
  _descriptor.MethodDescriptor(
    name='SendCommand',
    full_name='ansys.api.mapdl.v0.MapdlService.SendCommand',
    index=0,
    containing_service=None,
    input_type=_CMDREQUEST,
    output_type=_CMDRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SendCommandS',
    full_name='ansys.api.mapdl.v0.MapdlService.SendCommandS',
    index=1,
    containing_service=None,
    input_type=_CMDREQUEST,
    output_type=_CMDOUTPUT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InputFileLocal',
    full_name='ansys.api.mapdl.v0.MapdlService.InputFileLocal',
    index=2,
    containing_service=None,
    input_type=_CMDREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InputFile',
    full_name='ansys.api.mapdl.v0.MapdlService.InputFile',
    index=3,
    containing_service=None,
    input_type=_INPUTFILEREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='InputFileS',
    full_name='ansys.api.mapdl.v0.MapdlService.InputFileS',
    index=4,
    containing_service=None,
    input_type=_INPUTFILEREQUEST,
    output_type=_CMDOUTPUT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='FctCall',
    full_name='ansys.api.mapdl.v0.MapdlService.FctCall',
    index=5,
    containing_service=None,
    input_type=_FCTCALLREQUEST,
    output_type=_FCTCALLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetNodes',
    full_name='ansys.api.mapdl.v0.MapdlService.GetNodes',
    index=6,
    containing_service=None,
    input_type=ansys__kernel__pb2._EMPTYREQUEST,
    output_type=ansys__kernel__pb2._NODE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetNode',
    full_name='ansys.api.mapdl.v0.MapdlService.GetNode',
    index=7,
    containing_service=None,
    input_type=_NODEREQUEST,
    output_type=_NODERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetNode',
    full_name='ansys.api.mapdl.v0.MapdlService.SetNode',
    index=8,
    containing_service=None,
    input_type=_SETNODEREQUEST,
    output_type=_SETNODERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Nodes',
    full_name='ansys.api.mapdl.v0.MapdlService.Nodes',
    index=9,
    containing_service=None,
    input_type=ansys__kernel__pb2._EMPTYREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetElements',
    full_name='ansys.api.mapdl.v0.MapdlService.GetElements',
    index=10,
    containing_service=None,
    input_type=ansys__kernel__pb2._EMPTYREQUEST,
    output_type=_ELEMENT,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetElement',
    full_name='ansys.api.mapdl.v0.MapdlService.GetElement',
    index=11,
    containing_service=None,
    input_type=_ELEMENTREQUEST,
    output_type=_ELEMENTRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LoadElements',
    full_name='ansys.api.mapdl.v0.MapdlService.LoadElements',
    index=12,
    containing_service=None,
    input_type=ansys__kernel__pb2._EMPTYREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetElementType',
    full_name='ansys.api.mapdl.v0.MapdlService.GetElementType',
    index=13,
    containing_service=None,
    input_type=_ELEMENTREQUEST,
    output_type=_ELEMENTTYPE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='LoadElementTypeDescription',
    full_name='ansys.api.mapdl.v0.MapdlService.LoadElementTypeDescription',
    index=14,
    containing_service=None,
    input_type=ansys__kernel__pb2._EMPTYREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetParameter',
    full_name='ansys.api.mapdl.v0.MapdlService.GetParameter',
    index=15,
    containing_service=None,
    input_type=_PARAMETERREQUEST,
    output_type=_PARAMETERRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetVariable',
    full_name='ansys.api.mapdl.v0.MapdlService.GetVariable',
    index=16,
    containing_service=None,
    input_type=_VARIABLEREQUEST,
    output_type=_VARIABLERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Get',
    full_name='ansys.api.mapdl.v0.MapdlService.Get',
    index=17,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_GETRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='VGet',
    full_name='ansys.api.mapdl.v0.MapdlService.VGet',
    index=18,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=_VARIABLERESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='VGet2',
    full_name='ansys.api.mapdl.v0.MapdlService.VGet2',
    index=19,
    containing_service=None,
    input_type=_GETREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='Ctrl',
    full_name='ansys.api.mapdl.v0.MapdlService.Ctrl',
    index=20,
    containing_service=None,
    input_type=ansys__kernel__pb2._CTRLREQUEST,
    output_type=ansys__kernel__pb2._CTRLRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetVtkGeometry',
    full_name='ansys.api.mapdl.v0.MapdlService.GetVtkGeometry',
    index=21,
    containing_service=None,
    input_type=ansys__kernel__pb2._EMPTYREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetDataInfo',
    full_name='ansys.api.mapdl.v0.MapdlService.GetDataInfo',
    index=22,
    containing_service=None,
    input_type=_PARAMETERREQUEST,
    output_type=_DATARESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetVecData',
    full_name='ansys.api.mapdl.v0.MapdlService.GetVecData',
    index=23,
    containing_service=None,
    input_type=_PARAMETERREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='GetMatData',
    full_name='ansys.api.mapdl.v0.MapdlService.GetMatData',
    index=24,
    containing_service=None,
    input_type=_PARAMETERREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetVecData',
    full_name='ansys.api.mapdl.v0.MapdlService.SetVecData',
    index=25,
    containing_service=None,
    input_type=_SETVECDATAREQUEST,
    output_type=ansys__kernel__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='SetMatData',
    full_name='ansys.api.mapdl.v0.MapdlService.SetMatData',
    index=26,
    containing_service=None,
    input_type=_SETMATDATAREQUEST,
    output_type=ansys__kernel__pb2._EMPTYRESPONSE,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='UploadFile',
    full_name='ansys.api.mapdl.v0.MapdlService.UploadFile',
    index=27,
    containing_service=None,
    input_type=_UPLOADFILEREQUEST,
    output_type=_UPLOADFILEREPLY,
    serialized_options=None,
  ),
  _descriptor.MethodDescriptor(
    name='DownloadFile',
    full_name='ansys.api.mapdl.v0.MapdlService.DownloadFile',
    index=28,
    containing_service=None,
    input_type=_DOWNLOADFILEREQUEST,
    output_type=ansys__kernel__pb2._CHUNK,
    serialized_options=None,
  ),
])
_sym_db.RegisterServiceDescriptor(_MAPDLSERVICE)

DESCRIPTOR.services_by_name['MapdlService'] = _MAPDLSERVICE

# @@protoc_insertion_point(module_scope)
