"""Installation file for the ansys-api-mapdl-v0 package"""

import os
from setuptools import setup

install_requires = ['grpcio',
                    'google-api-python-client',
                    'protobuf']

# Get the long description from the README file
HERE = os.path.abspath(os.path.dirname(__file__))
with open(os.path.join(HERE, 'README.rst'), encoding='utf-8') as f:
    long_description = f.read()

desc = 'Autogenerated python gRPC interface package for ansys-api-mapdl-v0 built on 04:49:37 on 29 October 2021'

setup(
    name='ansys-api-mapdl-v0',
    packages=['ansys.api.mapdl.v0'],
    version='0.4.1',
    license='MIT',
    url='https://github.com/pyansys/',
    author='Ansys Inc.',
    author_email='support@ansys.com',
    description=desc,
    long_description=long_description,
    long_description_content_type='text/markdown',
    python_requires='>=3.5.*',
    install_requires=install_requires,
)
